@@ -64,15 +64,15 @@ with open(os.path.join(abs_path, rel_path)) as json_file:
 
 
 def _get_block_length(lines, k):
-    """ Calculates the length (in number of lines) of a edit of added/deleted
-        lines starting in a given line k.
+    """
+    Calculates the length (in number of lines) of a edit of added/deleted
+    lines starting in a given line k.
 
-    Args:
-        lines: dictionary of added or deleted lines
-        k: line number to check for
+    :param dict lines: dictionary of added or deleted lines
+    :param int k: line number to check for
 
-    Returns:
-        block_size: number of lines in the contiguously block that was modified
+    :return:
+        *int* – number of lines in the contiguously block that was modified
     """
 
     if k not in lines or (k > 1 and k - 1 in lines):
@@ -91,17 +91,17 @@ def _get_block_length(lines, k):
 
 
 def _identify_edits(deleted_lines, added_lines, extraction_settings):
-    """ Maps line numbers between the pre- and post-commit version of a
-        modification.
+    """
+    Maps line numbers between the pre- and post-commit version of a
+    modification.
 
-    Args:
-        deleted_lines: dictionary of deleted lines
-        added_lines: dictionary of added lines
-        extraction_settings: settings for the extraction
+    :param dict deleted_lines: dictionary of deleted lines
+    :param dict added_lines: dictionary of added lines
+    :param dict extraction_settings: settings for the extraction
 
-    Returns:
-        pre_to_post: dictionary mapping line numbers before and after commit
-        edits: dataframe with information on edits
+    :return:
+        - *dict* – dictionary mapping line numbers before and after commit
+        - *pandas.DataFrame* – dataframe with information on edits
     """
 
     # either deleted or added lines must contain items otherwise there would
@@ -227,13 +227,13 @@ def _identify_edits(deleted_lines, added_lines, extraction_settings):
 
 
 def text_entropy(text):
-    """ Computes entropy for a given text based on UTF8 alphabet.
+    """
+    Computes entropy for a given text based on UTF8 alphabet.
 
-    Args:
-        text: string to compute the text entropy for
+    :param str text: string to compute the text entropy for
 
-    Returns:
-        text_entropy: text entropy of the given string
+    :return:
+        *float* – text entropy of the given string
     """
     # we only consider UTF8 characters to compute the text entropy
     pk = [text.count(chr(i)) for i in range(256)]
@@ -245,13 +245,13 @@ def text_entropy(text):
 
 
 def get_commit_dag(git_repo_dir):
-    """ Extracts commit dag from given path to git repository.
+    """
+    Extracts commit dag from given path to git repository.
 
-    Args:
-        git_repo_dir: path to the git repository that is mined
+    :param str git_repo_dir: path to the git repository that is mined
 
-    Returns:
-        dag: dag linking successive commits in the same branch
+    :return:
+        *pathpy.DAG* – dag linking successive commits in the same branch
     """
     git_repo = pydriller.Git(git_repo_dir)
     commits = [x.hash[0:7] for x in git_repo.get_list_commits()]
@@ -263,14 +263,14 @@ def get_commit_dag(git_repo_dir):
 
 
 def _parse_blame_C(blame_C):
-    """ Converts the input provided for the copy option in git blame to a list
-        of options required as input for gitpython.
+    """
+    Converts the input provided for the copy option in git blame to a list
+    of options required as input for gitpython.
 
-    Args:
-        blame_C: string defining how the copy option in git blame is used
+    :param str blame_C: string defining how the copy option in git blame is used
 
-    Returns:
-        list_of_arguments: list of parameters for gitpython blame
+    :return:
+        *list* – list of parameters for gitpython blame
     """
     pattern = re.compile("(^$|^-?C{0,3}[0-9]*$)")
     if not pattern.match(blame_C):
@@ -288,14 +288,14 @@ def _parse_blame_C(blame_C):
 
 
 def _parse_porcelain_blame(blame):
-    """ Parses the porcelain output of git blame and returns content as
-        dataframe.
+    """
+    Parses the porcelain output of git blame and returns content as
+    dataframe.
 
-    Args:
-        blame: porcelain output of git blame
+    :param str blame: porcelain output of git blame
 
-    Returns:
-        blame_info: content of blame as pandas dataframe
+    :return:
+        *dict* – content of blame as pandas dataframe
     """
     l = {'original_commit_hash': [],
          'original_line_no': [],
@@ -329,21 +329,19 @@ def _parse_porcelain_blame(blame):
 def _get_edit_details(edit, commit, deleted_lines, added_lines,
                       blame_info_parent, blame_info_commit,
                       extraction_settings):
-    """ Extracts detailed measures for a given edit.
+    """
+    Extracts detailed measures for a given edit.
 
-    Args:
-        edit: edit as identified in _identify_edits
-        commit: pydriller commit object containing the edit
-        deleted_lines: dict of added lines
-        added_lines: dict of deleted lines
-        blame_info_parent: blame info for parent commit as output from
-                           _parse_porcelain_blame
-        blame_info_commit: blame info for current commit as output from
-                           _parse_porcelain_blame
-        extraction_settings: settings for the extraction
+    :param dict edit: edit as identified in _identify_edits
+    :param pydriller.Commit commit: pydriller commit object containing the edit
+    :param dict deleted_lines: dict of added lines
+    :param dict added_lines: dict of deleted lines
+    :param str blame_info_parent: blame info for parent commit as output from _parse_porcelain_blame
+    :param str blame_info_commit: blame info for current commit as output from _parse_porcelain_blame
+    :param dict extraction_settings: settings for the extraction
 
-    Returns:
-        e: pandas dataframe containing information on edits
+    :return:
+        *pandas.DataFrame* – pandas dataframe containing information on edits
     """
     # Different actions for different types of edits.
     e = {}
@@ -582,6 +580,16 @@ def _get_edit_details(edit, commit, deleted_lines, added_lines,
 
 
 def is_binary_file(filename, file_content):
+    """
+    Detects if a file with given content is a binary file.
+    
+    :param str filename: name of the file including its file extension
+    :param str file_content: content of the file
+    
+    :returns:
+        *bool* – True if binary file is detected, otherwise False
+    """
+    
     if filename is None:
         return False
     else:
@@ -602,17 +610,16 @@ def is_binary_file(filename, file_content):
 
 
 def _extract_edits(git_repo, commit, modification, extraction_settings):
-    """ Returns dataframe with metadata on edits made in a given modification.
+    """
+    Returns dataframe with metadata on edits made in a given modification.
 
-    Args:
-        git_repo: pydriller Git object
-        commit: pydriller Commit object
-        modification: pydriller ModificationFile object
-        extraction_settings: settings for the extraction
+    :param pydriller.Git git_repo: pydriller Git object
+    :param pydriller.Commit commit: pydriller Commit object
+    :param pydriller.ModifiedFile modification: pydriller ModifiedFile object
+    :param dict extraction_settings: settings for the extraction
 
-    Returns:
-        edits_info: pandas DataFrame object containing metadata on all edits in
-                    given modification
+    :return:
+        *pandas.DataFrame* – pandas DataFrame object containing metadata on all edits in given modification
     """
 
     binary_file = is_binary_file(modification.filename, modification.diff)
@@ -712,18 +719,11 @@ def _extract_edits(git_repo, commit, modification, extraction_settings):
             if edit.type == 'binary_file_change':
                 e['new_path'] = edit.new_path
                 e['old_path'] = edit.old_path
-                if extraction_settings['extract_complexity']:
-                    e['cyclomatic_complexity_of_file'] = None
-                    e['lines_of_code_in_file'] = None
                 e['total_added_lines'] = None
                 e['total_removed_lines'] = None
             else:
                 e['new_path'] = modification.new_path
                 e['old_path'] = modification.old_path
-                if extraction_settings['extract_complexity']:
-                    e['cyclomatic_complexity_of_file'] = \
-                        modification.complexity
-                    e['lines_of_code_in_file'] = modification.nloc
                 e['total_added_lines'] = modification.added_lines
                 e['total_removed_lines'] = modification.deleted_lines
             e['filename'] = modification.filename
@@ -743,19 +743,17 @@ def _extract_edits(git_repo, commit, modification, extraction_settings):
 
 def _extract_edits_merge(git_repo, commit, modification_info,
                          extraction_settings):
-    """ Returns dataframe with metadata on edits made in a given modification
-        for merge commits.
+    """
+    Returns dataframe with metadata on edits made in a given modification
+    for merge commits.
 
-    Args:
-        git_repo: pydriller Git object
-        commit: pydriller Commit object
-        modification_info: information on the modification as stored in a
-                           pydriller ModificationFile.
-        extraction_settings: settings for the extraction
+    :param str git_repo: pydriller Git object
+    :param pydriller.Commit commit: pydriller Commit object
+    :param pydriller.ModifiedFile modification_info: information on the modification as stored in a pydriller ModifiedFile.
+    :param dict extraction_settings: settings for the extraction
 
-    Returns:
-        edits_info: pandas DataFrame object containing metadata on all edits in
-                    given modification
+    :return:
+        *pandas.DataFrame* – pandas DataFrame object containing metadata on all edits in given modification
     """
     assert commit.merge
     # With merges, the following cases can occur:
@@ -956,26 +954,26 @@ def _extract_edits_merge(git_repo, commit, modification_info,
 
 
 def _get_edited_file_paths_since_split(git_repo, commit):
-    """ For a merge commit returns list of all files edited since the last
-        creation of a new branch relevant for the merge.
-
-    Args:
-        git_repo: pydriller Git object
-        commit: pydriller Commit object
-
-    Returns:
-        edited_file_paths: list of paths to the edited files
     """
+    For a merge commit returns list of all files edited since the last
+    creation of a new branch relevant for the merge.
+
+    :param pydriller.Git git_repo: pydriller Git object
+    :param pydriller.Commit commit: pydriller Commit object
+
+    :return:
+        *List* – list of paths to the edited files
+    """
+    
     def expand_dag(dag, leafs):
-        """ Expands a dag by adding the parents of a given set of nodes to the
-            dag.
+        """
+        Expands a dag by adding the parents of a given set of nodes to the dag.
 
-        Args:
-            dag: pathpy DAG object
-            leafs: set of nodes that are expanded
-
-        Returns:
-            dag: the expanded pathpy DAG object
+        :param pathpy.DAG dag: pathpy DAG object
+        :param set leafs: set of nodes that are expanded
+        
+        :return:
+            *pathpy.DAG* – the expanded pathpy DAG object
         """
         for node in leafs:
             parents = git_repo.get_commit(node).parents
@@ -984,14 +982,14 @@ def _get_edited_file_paths_since_split(git_repo, commit):
         return dag
 
     def common_node_on_paths(paths):
-        """ Computes the overlap between given sets of nodes. Returns the nodes
-            present in all sets.
+        """
+        Computes the overlap between given sets of nodes. Returns the nodes
+        present in all sets.
 
-        Args:
-            paths: list of node sequences
+        :param List paths: list of node sequences
 
-        Returns:
-            common_nodes: set of nodes that are present on all paths
+        :return:
+            *set* – set of nodes that are present on all paths
         """
         # Drop first and last element of the path.
         common_nodes = set(paths[0][1:-1])
@@ -1001,14 +999,14 @@ def _get_edited_file_paths_since_split(git_repo, commit):
         return common_nodes
 
     def remove_successors(dag, node):
-        """ Removes all successors of a node from a given dag.
+        """
+        Removes all successors of a node from a given dag.
 
-        Args:
-            dag: pathpy DAG object
-            node: node for which successors shall be removed
+        :param pathpy.DAG dag: pathpy DAG object
+        :param str node: node for which successors shall be removed
 
-        Returns:
-            dag: reduced pathpy DAG object
+        :return:
+            *pathpy.DAG* – reduced pathpy DAG object
         """
         rm = [n for nl in [x[1:] for x in dag.routes_from_node(node)]
               for n in nl]
@@ -1051,17 +1049,17 @@ def _get_edited_file_paths_since_split(git_repo, commit):
 
 
 def _check_mailmap(name, email, git_repo):
-    """ Returns matching user from git .mailmap file if available. Returns
-        input if user is not in mailmap or mailmap is unavailable.
+    """
+    Returns matching user from git .mailmap file if available. Returns
+    input if user is not in mailmap or mailmap is unavailable.
 
-    Args:
-        name: username
-        email: git email
-        git_repo: PyDriller Git object
+    'param str name: username
+    'param str email: git email
+    'param pydriller.Git git_repo: PyDriller Git object
 
-    Returns:
-        name: corresponding username from mailmap
-        email: corresponding email from mailmap
+    :return:
+        - *str* – corresponding username from mailmap
+        - *str* – corresponding email from mailmap
     """
     test_str = '{} <{}>'.format(name, email)
     out_str = git.Git(str(git_repo.path)).check_mailmap(test_str)
@@ -1078,19 +1076,18 @@ def _check_mailmap(name, email, git_repo):
 
 
 def _process_commit(args):
-    """ Extracts information on commit and all edits made with the commit.
+    """
+    Extracts information on commit and all edits made with the commit.
 
-    Args:
-        args: dictionary with arguments. For multiprocessing, function can only
-              take single input.
-              Dictionary must contain:
-                  git_repo_dir: path to the git repository that is mined
-                  commit_hash: hash of the commit that is processed
-                  extraction_settings: settings for the extraction
+    :param dict args: dictionary with arguments. For multiprocessing, function can only
+                      take single input.
+                      Dictionary must contain:
+                          git_repo_dir: path to the git repository that is mined
+                          commit_hash: hash of the commit that is processed
+                          extraction_settings: settings for the extraction
 
-    Returns:
-        extracted_result: dict containing two dataframes with information of
-                          commit and edits
+    :return:
+        *dict* – dict containing two dataframes with information of commit and edits
     """
     with git_init_lock:
         git_repo = pydriller.Git(args['git_repo_dir'])
@@ -1165,17 +1162,6 @@ def _process_commit(args):
                                                 .format(commit.hash,
                                                         edited_file_path))
 
-                        if is_binary_file(edited_file_path, file_content):
-                            if args['extraction_settings']['extract_complexity']:
-                                modification_info['cyclomatic_complexity_of_file'] = None
-                                modification_info['lines_of_code_in_file'] = None
-                        else:
-                            if args['extraction_settings']['extract_complexity']:
-                                l = lizard.analyze_file \
-                                          .analyze_source_code(edited_file_path,
-                                                               file_content)
-                                modification_info['cyclomatic_complexity_of_file'] = l.CCN
-                                modification_info['lines_of_code_in_file'] = l.nloc
                         modification_info['filename'] = edited_file_path.split(os.sep)[-1]
                         modification_info['new_path'] = edited_file_path
                         modification_info['old_path'] = edited_file_path
@@ -1201,9 +1187,6 @@ def _process_commit(args):
                             # File was deleted.
                             modification_info['new_path'] = None
                             modification_info['old_path'] = edited_file_path
-                            if args['extraction_settings']['extract_complexity']:
-                                modification_info['cyclomatic_complexity_of_file'] = 0
-                                modification_info['lines_of_code_in_file'] = 0
                             modification_info['modification_type'] = 'merge_self_accept'
 
                             df_edits = pd.concat(
@@ -1254,17 +1237,16 @@ def _process_commit(args):
 
 def _process_repo_serial(git_repo_dir, sqlite_db_file, commits,
                          extraction_settings):
-    """ Processes all commits in a given git repository in a serial manner.
+    """
+    Processes all commits in a given git repository in a serial manner.
 
-    Args:
-        git_repo_dir: path to the git repository that is mined
-        sqlite_db_file: path (including database name) where the sqlite
-                        database will be created
-        commits: list of commits that have to be processed
-        extraction_settings: settings for the extraction
+    :param str git_repo_dir: path to the git repository that is mined
+    :param str sqlite_db_file: path (including database name) where the sqlite database will be created
+    :param List[str] commits: list of commits that have to be processed
+    :param dict extraction_settings: settings for the extraction
 
-    Returns:
-        sqlite database will be written at specified location
+    :return:
+        SQLite database will be written at specified location
     """
 
     # git_repo = pydriller.Git(git_repo_dir)
@@ -1291,17 +1273,16 @@ def _init(git_repo_dir, git_init_lock_):
 
 def _process_repo_parallel(git_repo_dir, sqlite_db_file, commits,
                            extraction_settings):
-    """ Processes all commits in a given git repository in a parallel manner.
+    """
+    Processes all commits in a given git repository in a parallel manner.
 
-    Args:
-        git_repo_dir: path to the git repository that is mined
-        sqlite_db_file: path (including database name) where the sqlite
-                        database will be created
-        commits: list of commits that are already in the database
-        extraction_settings: settings for the extraction
+    :param str git_repo_dir: path to the git repository that is mined
+    :param str sqlite_db_file: path (including database name) where the sqlite database will be created
+    :param List[str] commits: list of commits that are already in the database
+    :param dict extraction_settings: settings for the extraction
 
-    Returns:
-        sqlite database will be written at specified location
+    :return:
+        SQLite database will be written at specified location
     """
 
     args = [{'git_repo_dir': git_repo_dir, 'commit_hash': commit.hash,
@@ -1328,15 +1309,14 @@ def _process_repo_parallel(git_repo_dir, sqlite_db_file, commits,
 
 
 def identify_file_renaming(git_repo_dir):
-    """ Identifies all names and locations different files in a repository have
-        had.
+    """
+    Identifies all names and locations different files in a repository have had.
 
-    Args:
-        git_repo_dir: path to the git repository that is mined
+    :param str git_repo_dir: path to the git repository that is mined
 
-    Returns:
-        dag: pathpy DAG object depicting the renaming process
-        aliases: dictionary containing all aliases for all files
+    :return:
+        - *pathpy.DAG* – pathpy DAG object depicting the renaming process
+        - *dict* – dictionary containing all aliases for all files
     """
 
     # TODO: Consider corner case where file is renamed and new file with old
@@ -1372,18 +1352,17 @@ def identify_file_renaming(git_repo_dir):
 
 
 def get_unified_changes(git_repo_dir, commit_hash, file_path):
-    """ Returns dataframe with github-like unified diff representation of the
-        content of a file before and after a commit for a given git repository,
-        commit hash and file path.
+    """
+    Returns dataframe with github-like unified diff representation of the
+    content of a file before and after a commit for a given git repository,
+    commit hash and file path.
 
-    Args:
-        git_repo_dir: path to the git repository that is mined
-        commit_hash: commit hash for which the changes are computed
-        file_path: path to file (within the repository) for which the changes
-                   are computed
+    :param str git_repo_dir: path to the git repository that is mined
+    :param str commit_hash: commit hash for which the changes are computed
+    :param str file_path: path to file (within the repository) for which the changes are computed
 
-    Returns:
-        df: pandas dataframe listing changes made to file in commit
+    :return:
+        *pandas.DataFrame* – pandas dataframe listing changes made to file in commit
     """
     git_repo = pydriller.Git(git_repo_dir)
     commit = git_repo.get_commit(commit_hash)
@@ -1447,16 +1426,15 @@ def get_unified_changes(git_repo_dir, commit_hash, file_path):
 
 def check_mining_complete(git_repo_dir, sqlite_db_file, commits=[],
                           all_branches=False, return_number_missing=False):
-    """ Checks status of a mining operation
+    """
+    Checks status of a mining operation
 
-    Args:
-        git_repo_dir: path to the git repository that is mined
-        sqlite_db_file: path (including database name) where with sqlite
-                        database
-        commits: only consider specific set of commits, considers all if empty
+    :param str git_repo_dir: path to the git repository that is mined
+    :param str sqlite_db_file: path (including database name) where with sqlite database
+    :param List[str] commits: only consider specific set of commits, considers all if empty
 
-    Returns:
-        True if all commits are included in the database, otherwise False
+    :return:
+        *bool* – True if all commits are included in the database, otherwise False
     """
     git_repo = pydriller.Git(git_repo_dir)
     if os.path.exists(sqlite_db_file):
@@ -1488,16 +1466,15 @@ def check_mining_complete(git_repo_dir, sqlite_db_file, commits=[],
 
 
 def mining_state_summary(git_repo_dir, sqlite_db_file, all_branches=False):
-    """ Prints mining progress of database and returns dataframe with details
-        on missing commits.
+    """
+    Prints mining progress of database and returns dataframe with details
+    on missing commits.
 
-    Args:
-        git_repo_dir: path to the git repository that is mined
-        sqlite_db_file: path (including database name) where with sqlite
-                        database
+    :param str git_repo_dir: path to the git repository that is mined
+    :param str sqlite_db_file: path (including database name) where with sqlite database
 
-    Returns:
-        dataframe with details on missing commits
+    :return:
+        *pandas.DataFrame* – dataframe with details on missing commits
     """
     git_repo = pydriller.Git(git_repo_dir)
     if os.path.exists(sqlite_db_file):
@@ -1575,35 +1552,29 @@ def mine_git_repo(git_repo_dir, sqlite_db_file, commits=[],
                   use_blocks=False, no_of_processes=os.cpu_count(),
                   chunksize=1, exclude=[], blame_C='', blame_w=False,
                   max_modifications=0, timeout=0, extract_text=False,
-                  extract_complexity=False, extract_merges=True,
-                  extract_merge_deletions=False, all_branches=False):
-    """ Creates sqlite database with details on commits and edits for a given
-        git repository.
+                  extract_merges=True, extract_merge_deletions=False,
+                  all_branches=False):
+    """
+    Creates sqlite database with details on commits and edits for a given
+    git repository.
 
-    Args:
-        git_repo_dir: path to the git repository that is mined
-        sqlite_db_file: path (including database name) where the sqlite
-                        database will be created
-        commits: only consider specific set of commits, considers all if empty
-        use_blocks: bool, determins if analysis is performed on block or line
-                    basis
-        no_of_processes: number of parallel processes that are spawned
-        chunksize: number of tasks that are assigned to a process at a time
-        exclude: file paths that are excluded from the analysis
-        blame_C: string for the blame C option following the pattern
-                 "-C[<num>]" (computationally expensive)
-        blame_w: bool, ignore whitespaces in git blame (-w option)
-        max_modifications: ignore commit if there are more modifications
-        timeout: stop processing commit after given time in seconds
-        extract_text: extract the commit message and line texts
-        extract_complexity: extract cyclomatic complexity and length of file
-                            (computationally expensive)
-        extract_merges: process merges
-        extract_merge_deletions: extract lines that are not accepted during a
-                                 merge as 'deletions'
+    :param str git_repo_dir: path to the git repository that is mined
+    :param str sqlite_db_file: path (including database name) where the sqlite database will be created
+    :param List[str] commits: only consider specific set of commits, considers all if empty
+    :param bool use_blocks: determins if analysis is performed on block or line basis
+    :param int no_of_processes: number of parallel processes that are spawned
+    :param int chunksize: number of tasks that are assigned to a process at a time
+    :param List[str] exclude: file paths that are excluded from the analysis
+    :param str blame_C: string for the blame C option following the pattern "-C[<num>]" (computationally expensive)
+    :param bool blame_w: bool, ignore whitespaces in git blame (-w option)
+    :param int max_modifications: ignore commit if there are more modifications
+    :param int timeout: stop processing commit after given time in seconds
+    :param bool extract_text: extract the commit message and line texts
+    :param bool extract_merges: process merges
+    :param bool extract_merge_deletions: extract lines that are not accepted during a merge as 'deletions'
 
-    Returns:
-        sqlite database will be written at specified location
+    :return:
+        SQLite database will be written at specified location
     """
     git_version = check_output(['git', '--version']).strip().decode("utf-8")
 
@@ -1620,7 +1591,7 @@ def mine_git_repo(git_repo_dir, sqlite_db_file, commits=[],
             (int(parsed_git_version[1]) == 11) and
             (int(parsed_git_version[2]) == 0)
        ):
-        raise Exception("Your system is using git " + git_version +
+        raise Exception("Your system is using " + git_version +
                         " which is not supported by git2net. " +
                         " Please update to git >= 2.11.1")
 
@@ -1637,7 +1608,6 @@ def mine_git_repo(git_repo_dir, sqlite_db_file, commits=[],
                            'max_modifications': max_modifications,
                            'timeout': timeout,
                            'extract_text': extract_text,
-                           'extract_complexity': extract_complexity,
                            'extract_merges': extract_merges,
                            'extract_merge_deletions': extract_merge_deletions}
 
@@ -1791,23 +1761,18 @@ def mine_git_repo(git_repo_dir, sqlite_db_file, commits=[],
 
 def mine_github(github_url, git_repo_dir, sqlite_db_file, branch=None,
                 **kwargs):
-    """ Clones a repository from github and starts the mining process.
+    """
+    Clones a repository from github and starts the mining process.
 
-    Args:
-        github_url: url to the publicly accessible github project that will be
-                    mined can be priovided as full url or <OWNER>/<REPOSITORY>
-        git_repo_dir: path to the git repository that is mined if path ends
-                      with '/' an additional folder will be created
-        sqlite_db_file: path (including database name) where the sqlite
-                        database will be created
-        branch: The branch of the github project that will be checked out and
-                mined. If no branch is provided the default branch of the
-                repository is used.
-        **kwargs: arguments that will be passed on to mine_git_repo
+    :param str github_url: url to the publicly accessible github project that will be mined can be priovided as full url or <OWNER>/<REPOSITORY>
+    :param str git_repo_dir: path to the git repository that is mined if path ends with '/' an additional folder will be created
+    :param str sqlite_db_file: path (including database name) where the sqlite database will be created
+    :param str branch: The branch of the github project that will be checked out and mined. If no branch is provided the default branch of the repository is used.
+    :param \**kwargs: arguments that will be passed on to mine_git_repo
 
-    Returns:
-        git repository will be cloned to specified location
-        sqlite database will be written at specified location
+    :return:
+        - git repository will be cloned to specified location
+        - SQLite database will be written at specified location
     """
     # github_url can either be provided as full url or as in form <USER>/<REPO>
     user_repo_pattern = r'^([^\/]*)\/([^\/]*)$'
